Index: /branches/eam_rel9_p0/psModules/src/objects/pmObjects.c
===================================================================
--- /branches/eam_rel9_p0/psModules/src/objects/pmObjects.c	(revision 5991)
+++ /branches/eam_rel9_p0/psModules/src/objects/pmObjects.c	(revision 5992)
@@ -6,6 +6,6 @@
  *  @author EAM, IfA: significant modifications.
  *
- *  @version $Revision: 1.5.4.1 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-01-10 04:46:03 $
+ *  @version $Revision: 1.5.4.2 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-01-15 18:21:49 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -77,5 +77,5 @@
     psFree(tmp->moments);
     psFree(tmp->modelPSF);
-    psFree(tmp->modelFLT);
+    psFree(tmp->modelEXT);
     psTrace(__func__, 4, "---- %s() end ----\n", __func__);
 }
@@ -211,5 +211,5 @@
     // XXX EAM : i changed this to match pmModelEval above, but see
     // XXX EAM   the note below in pmSourceContour
-    psF32 oldValue = pmModelEval(source->modelFLT, source->pixels, subCol, subRow);
+    psF32 oldValue = pmModelEval(source->modelEXT, source->pixels, subCol, subRow);
     if (oldValue == level) {
         psTrace(__func__, 4, "---- %s() end ----\n", __func__);
@@ -233,5 +233,5 @@
 
     while (subCol != lastColumn) {
-        psF32 newValue = pmModelEval(source->modelFLT, source->pixels, subCol, subRow);
+        psF32 newValue = pmModelEval(source->modelEXT, source->pixels, subCol, subRow);
         if (oldValue == level) {
             psTrace(__func__, 4, "---- %s() end ----\n", __func__);
@@ -312,5 +312,5 @@
     tmp->blends = NULL;
     tmp->modelPSF = NULL;
-    tmp->modelFLT = NULL;
+    tmp->modelEXT = NULL;
     tmp->type = PM_SOURCE_UNKNOWN;
     tmp->mode = PM_SOURCE_DEFAULT;
@@ -1163,5 +1163,5 @@
 
     int Nsat     = 0;
-    int Ngal     = 0;
+    int Next     = 0;
     int Nstar    = 0;
     int Npsf     = 0;
@@ -1223,9 +1223,9 @@
         }
 
         // likely unsaturated galaxy (too large to be stellar)
         if ((sigX > (clump.X + 3*clump.dX)) || (sigY > (clump.Y + 3*clump.dY))) {
-            tmpSrc->type = PM_SOURCE_GALAXY;
+            tmpSrc->type = PM_SOURCE_EXTENDED;
             tmpSrc->mode = PM_SOURCE_DEFAULT;
-            Ngal ++;
+            Next ++;
             continue;
         }
@@ -1261,5 +1261,5 @@
     psTrace (".pmObjects.pmSourceRoughClass", 2, "Nstar:    %3d\n", Nstar);
     psTrace (".pmObjects.pmSourceRoughClass", 2, "Npsf:     %3d\n", Npsf);
-    psTrace (".pmObjects.pmSourceRoughClass", 2, "Ngal:     %3d\n", Ngal);
+    psTrace (".pmObjects.pmSourceRoughClass", 2, "Next:     %3d\n", Next);
     psTrace (".pmObjects.pmSourceRoughClass", 2, "Nsatstar: %3d\n", Nsatstar);
     psTrace (".pmObjects.pmSourceRoughClass", 2, "Nsat:     %3d\n", Nsat);
@@ -1471,6 +1471,6 @@
     PS_ASSERT_PTR_NON_NULL(source->peak, false);
     PS_ASSERT_PTR_NON_NULL(source->pixels, false);
-    PS_ASSERT_PTR_NON_NULL(source->modelFLT, false);
-    // XXX EAM : what is the purpose of modelPSF/modelFLT?
+    PS_ASSERT_PTR_NON_NULL(source->modelEXT, false);
+    // XXX EAM : what is the purpose of modelPSF/modelEXT?
 
     //
@@ -1641,5 +1641,5 @@
                             PM_SOURCE_FIT_MODEL_TOLERANCE);
 
     // PSF model only fits first 4 parameters, FLT model fits all
     if (PSF) {
         paramMask = psVectorAlloc (params->n, PS_TYPE_U8);
@@ -1223,9 +1223,9 @@
         }
 
-        // likely unsaturated galaxy (too large to be stellar)
+        // likely unsaturated extended source (too large to be stellar)
         if ((sigX > (clump.X + 3*clump.dX)) || (sigY > (clump.Y + 3*clump.dY))) {
@@ -1641,5 +1641,5 @@
                             PM_SOURCE_FIT_MODEL_TOLERANCE);
 
-    // PSF model only fits first 4 parameters, FLT model fits all
+    // PSF model only fits first 4 parameters, EXT model fits all
     if (PSF) {
         paramMask = psVectorAlloc (params->n, PS_TYPE_U8);
Index: /branches/eam_rel9_p0/psModules/src/objects/pmPSFtry.c
===================================================================
--- /branches/eam_rel9_p0/psModules/src/objects/pmPSFtry.c	(revision 5991)
+++ /branches/eam_rel9_p0/psModules/src/objects/pmPSFtry.c	(revision 5992)
@@ -5,6 +5,6 @@
  *  @author EAM, IfA
  *
- *  @version $Revision: 1.3.4.2 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-01-14 07:02:53 $
+ *  @version $Revision: 1.3.4.3 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-01-15 18:23:13 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -33,5 +33,5 @@
     psFree (test->psf);
     psFree (test->sources);
-    psFree (test->modelFLT);
+    psFree (test->modelEXT);
     psFree (test->modelPSF);
     psFree (test->metric);
@@ -53,5 +53,5 @@
     test->psf      = pmPSFAlloc (type);
     test->sources  = psMemIncrRefCounter(sources);
-    test->modelFLT = psArrayAlloc (sources->n);
+    test->modelEXT = psArrayAlloc (sources->n);
     test->modelPSF = psArrayAlloc (sources->n);
     test->metric   = psVectorAlloc (sources->n, PS_TYPE_F64);
@@ -59,7 +59,7 @@
     test->mask     = psVectorAlloc (sources->n, PS_TYPE_U8);
 
-    for (int i = 0; i < test->modelFLT->n; i++) {
+    for (int i = 0; i < test->modelEXT->n; i++) {
         test->mask->data.U8[i]  = 0;
-        test->modelFLT->data[i] = NULL;
+        test->modelEXT->data[i] = NULL;
         test->modelPSF->data[i] = NULL;
         test->metric->data.F64[i] = 0;
@@ -87,5 +87,5 @@
     float x;
     float y;
-    int Nflt = 0;
+    int Next = 0;
     int Npsf = 0;
 
@@ -102,5 +102,5 @@
 
         // set temporary object mask and fit object
         // fit model as FLT, not PSF
         psImageKeepCircle (source->mask, x, y, RADIUS, "OR", PSPHOT_MASK_MARKED);
         status = pmSourceFitModel (source, model, false);
@@ -109,16 +109,16 @@
         // exclude the poor fits
         if (!status) {
-            psfTry->mask->data.U8[i] = PSFTRY_MASK_FLT_FAIL;
+            psfTry->mask->data.U8[i] = PSFTRY_MASK_EXT_FAIL;
             psFree (model);
             continue;
         }
-        psfTry->modelFLT->data[i] = model;
-        Nflt ++;
-    }
-    psLogMsg ("psphot.psftry", 4, "fit flt:   %f sec for %d sources\n", psTimerMark ("fit"), sources->n);
-    psTrace ("psphot.psftry", 3, "keeping %d of %d PSF candidates (FLT)\n", Nflt, sources->n);
+        psfTry->modelEXT->data[i] = model;
+        Next ++;
+    }
+    psLogMsg ("psphot.psftry", 4, "fit ext:   %f sec for %d sources\n", psTimerMark ("fit"), sources->n);
+    psTrace ("psphot.psftry", 3, "keeping %d of %d PSF candidates (EXT)\n", Next, sources->n);
 
     // stage 2: construct a psf (pmPSF) from this collection of model fits
-    pmPSFFromModels (psfTry->psf, psfTry->modelFLT, psfTry->mask);
+    pmPSFFromModels (psfTry->psf, psfTry->modelEXT, psfTry->mask);
 
     // stage 3: refit with fixed shape parameters
@@ -130,8 +130,8 @@
 
         pmSource *source = psfTry->sources->data[i];
-        pmModel  *modelFLT = psfTry->modelFLT->data[i];
+        pmModel  *modelEXT = psfTry->modelEXT->data[i];
 
         // set shape for this model based on PSF
-        pmModel *modelPSF = pmModelFromPSF (modelFLT, psfTry->psf);
+        pmModel *modelPSF = pmModelFromPSF (modelEXT, psfTry->psf);
         x = source->peak->x;
         y = source->peak->y;
@@ -102,5 +102,5 @@
 
         // set temporary object mask and fit object
-        // fit model as FLT, not PSF
+        // fit model as EXT, not PSF
         psImageKeepCircle (source->mask, x, y, RADIUS, "OR", PSPHOT_MASK_MARKED);
         status = pmSourceFitModel (source, model, false);
Index: /branches/eam_rel9_p0/psModules/src/objects/pmPSFtry.h
===================================================================
--- /branches/eam_rel9_p0/psModules/src/objects/pmPSFtry.h	(revision 5991)
+++ /branches/eam_rel9_p0/psModules/src/objects/pmPSFtry.h	(revision 5992)
@@ -6,6 +6,6 @@
  *  @author EAM, IfA
  *
- *  @version $Revision: 1.2.4.1 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-01-10 04:46:03 $
+ *  @version $Revision: 1.2.4.2 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-01-15 18:23:13 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -23,6 +23,6 @@
  * being tests, and contains an element to store the resulting psf
  * representation. In addition, this structure carries the complete collection of
  * FLT (floating parameter) and PSF (fixed parameter) model fits to each of the
  * sources modelFLT and modelPSF. It also contains a mask which is set by the
  * model fitting and psf fitting steps. For each model, the value of the quality
  * metric is stored in the vector metric and the fitted instrumental magnitude is
@@ -48,5 +48,5 @@
     pmPSF      *psf;                    ///< Add comment.
     psArray    *sources;                ///< pointers to the original sources
-    psArray    *modelFLT;               ///< model fits, floating parameters
+    psArray    *modelEXT;               ///< model fits, floating parameters
     psArray    *modelPSF;               ///< model fits, PSF parameters
     psVector   *mask;                   ///< Add comment.
@@ -66,5 +66,5 @@
     PSFTRY_MASK_CLEAR    = 0x00,        ///< Add comment.
     PSFTRY_MASK_OUTLIER  = 0x01,        ///< 1: outlier in psf polynomial fit (provided by psPolynomials)
-    PSFTRY_MASK_FLT_FAIL = 0x02,        ///< 2: flt model failed to converge
+    PSFTRY_MASK_EXT_FAIL = 0x02,        ///< 2: ext model failed to converge
     PSFTRY_MASK_PSF_FAIL = 0x04,        ///< 3: psf model failed to converge
     PSFTRY_MASK_BAD_PHOT = 0x08,        ///< 4: invalid source photometry
@@ -23,6 +23,6 @@
  * being tests, and contains an element to store the resulting psf
  * representation. In addition, this structure carries the complete collection of
- * FLT (floating parameter) and PSF (fixed parameter) model fits to each of the
- * sources modelFLT and modelPSF. It also contains a mask which is set by the
+ * EXT (floating parameter) and PSF (fixed parameter) model fits to each of the
+ * sources modelEXT and modelPSF. It also contains a mask which is set by the
  * model fitting and psf fitting steps. For each model, the value of the quality
  * metric is stored in the vector metric and the fitted instrumental magnitude is
